@@ -1163,10 +1163,11 @@ def apple_silicon_cache_size(cache_level: int) -> int:
 
 
 def get_cache_info(cache_level: int) -> tuple:
-    result = subprocess.run(["lscpu", "--json"], capture_output=True, text=True)
-    lscpu_info = json.loads(result.stdout)
     if cache_level == 0:
         cache_level = "1d"
+
+    result = subprocess.run(["lscpu", "--json"], capture_output=True, check=True, text=True)
+    lscpu_info = json.loads(result.stdout)
     for entry in lscpu_info["lscpu"]:
         if entry["field"] == f"L{cache_level} cache:":
             size_str, instances_str = entry["data"].split(" (")
@@ -1467,7 +1468,7 @@ def compute_chunks_blocks(  # noqa: C901
 
     # Return an arbitrary value for chunks and blocks when shape has any 0 dim
     if 0 in shape:
-        return (1,) * len(shape), (1,) * len(shape)
+        return shape, shape
 
     if blocks:
         if not isinstance(blocks, tuple | list):
